## Contributing
Please feel free to contribute! I am relatively new to sage, gap and genome rearrangement modelling! Even if you aren't able to contrbute code yourself, feel free to open an issue if you feel like something could be improved.

### Guidelines
1. Please search the issues tab before opening a pull-request and open new issues if necessary.
2. If your PR includes an enhancement, please try to write unit tests to go along with it.
3. Run tests on your local machine before opening a pull-request (see below).
4. If you have issues contributing, please open a new issue or post in the discussions tab.

### Testing
Tests are written and run using `pytest`.
Ensure you have pytest installed using 
`sage -pip install pytest`

To run tests, in the repository root directory simply run `sage -python -m pytest ./cgt`.
